@@ -2,14 +2,16 @@ use strict;
 
 package Path::Class::File;
 {
-  $Path::Class::File::VERSION = '0.32';
+  $Path::Class::File::VERSION = '0.34';
 }
 
 use Path::Class::Dir;
-use base qw(Path::Class::Entity);
+use parent qw(Path::Class::Entity);
 use Carp;
 
 use IO::File ();
+use Perl::OSType ();
+use File::Copy ();
 
 sub new {
   my $self = shift->SUPER::new;
@@ -17,14 +19,14 @@ sub new {
   my @dirs = @_;
 
   my ($volume, $dirs, $base) = $self->_spec->splitpath($file);
-  
+
   if (length $dirs) {
     push @dirs, $self->_spec->catpath($volume, $dirs, '');
   }
-  
+
   $self->{dir}  = @dirs ? $self->dir_class->new(@dirs) : undef;
   $self->{file} = $base;
-  
+
   return $self;
 }
 
@@ -74,8 +76,7 @@ sub opena { $_[0]->open('a') or croak "Can't append to $_[0]: $!" }
 sub touch {
   my $self = shift;
   if (-e $self) {
-    my $now = time();
-    utime $now, $now, $self;
+    utime undef, undef, $self;
   } else {
     $self->openw;
   }
@@ -132,6 +133,23 @@ sub spew {
     return;
 }
 
+sub spew_lines {
+    my $self = shift;
+    my %args = splice( @_, 0, @_-1 );
+
+    my $content = $_[0];
+
+    # If content is an array ref, appends $/ to each element of the array.
+    # Otherwise, if it is a simple scalar, just appends $/ to that scalar.
+
+    $content
+        = ref( $content ) eq 'ARRAY'
+        ? [ map { $_, $/ } @$content ]
+        : "$content$/";
+
+    return $self->spew( %args, $content );
+}
+
 sub remove {
   my $file = shift->stringify;
   return unlink $file unless -e $file; # Sets $! correctly
@@ -139,6 +157,49 @@ sub remove {
   return not -e $file;
 }
 
+sub copy_to {
+  my ($self, $dest) = @_;
+  if ( UNIVERSAL::isa($dest, Path::Class::File::) ) {
+    $dest = $dest->stringify;
+    die "Can't copy to file $dest: it is a directory" if -d $dest;
+  } elsif ( UNIVERSAL::isa($dest, Path::Class::Dir::) ) {
+    $dest = $dest->stringify;
+    die "Can't copy to directory $dest: it is a file" if -f $dest;
+    die "Can't copy to directory $dest: no such directory" unless -d $dest;
+  } elsif ( ref $dest ) {
+    die "Don't know how to copy files to objects of type '".ref($self)."'";
+  }
+
+  if ( !Perl::OSType::is_os_type('Unix') ) {
+
+      return unless File::Copy::cp($self->stringify, "${dest}");
+
+  } else {
+
+      return unless (system('cp', $self->stringify, "${dest}") == 0);
+
+  }
+
+  return $self->new($dest);
+}
+
+sub move_to {
+  my ($self, $dest) = @_;
+  if (File::Copy::move($self->stringify, "${dest}")) {
+
+      my $new = $self->new($dest);
+
+      $self->{$_} = $new->{$_} foreach (qw/ dir file /);
+
+      return $self;
+
+  } else {
+
+      return;
+
+  }
+}
+
 sub traverse {
   my $self = shift;
   my ($callback, @args) = @_;
@@ -160,29 +221,29 @@ Path::Class::File - Objects representing files
 
 =head1 VERSION
 
-version 0.32
+version 0.34
 
 =head1 SYNOPSIS
 
-  use Path::Class qw(file);  # Export a short constructor
-  
+  use Path::Class;  # Exports file() by default
+
   my $file = file('foo', 'bar.txt');  # Path::Class::File object
   my $file = Path::Class::File->new('foo', 'bar.txt'); # Same thing
-  
+
   # Stringifies to 'foo/bar.txt' on Unix, 'foo\bar.txt' on Windows, etc.
   print "file: $file\n";
-  
+
   if ($file->is_absolute) { ... }
   if ($file->is_relative) { ... }
-  
+
   my $v = $file->volume; # Could be 'C:' on Windows, empty string
                          # on Unix, 'Macintosh HD:' on Mac OS
-  
+
   $file->cleanup; # Perform logical cleanup of pathname
   $file->resolve; # Perform physical cleanup of pathname
-  
+
   my $dir = $file->dir;  # A Path::Class::Dir object
-  
+
   my $abs = $file->absolute; # Transform to absolute path
   my $rel = $file->relative; # Transform to relative path
 
@@ -388,7 +449,7 @@ a I<reading> mode.
 
 The default C<iomode> is C<r>.
 
-Lines can also be automatically splitted, mimicking the perl command-line
+Lines can also be automatically split, mimicking the perl command-line
 option C<-a> by using the C<split> parameter. If this parameter is used,
 each line will be returned as an array ref.
 
@@ -413,6 +474,15 @@ opening the file, just like L</slurp> supports.
 
 The default C<iomode> is C<w>.
 
+=item $file->spew_lines( $content );
+
+Just like C<spew>, but, if $content is a plain scalar, appends $/
+to it, or, if $content is an array ref, appends $/ to each element
+of the array.
+
+Can also take an C<iomode> parameter like C<spew>. Again, the
+default C<iomode> is C<w>.
+
 =item $file->traverse(sub { ... }, @args)
 
 Calls the given callback on $file. This doesn't do much on its own,
@@ -422,7 +492,7 @@ but see the associated documentation in L<Path::Class::Dir>.
 
 This method will remove the file in a way that works well on all
 platforms, and returns a boolean value indicating whether or not the
-file was successfully removed.  
+file was successfully removed.
 
 C<remove()> is better than simply calling Perl's C<unlink()> function,
 because on some platforms (notably VMS) you actually may need to call
@@ -445,6 +515,17 @@ Returns the class which should be used to create directory objects.
 
 Generally overridden whenever this class is subclassed.
 
+=item $copy = $file->copy_to( $dest );
+
+Copies the C<$file> to C<$dest>. It returns a L<Path::Class::File>
+object when successful, C<undef> otherwise.
+
+=item $moved = $file->move_to( $dest );
+
+Moves the C<$file> to C<$dest>, and updates C<$file> accordingly.
+
+It returns C<$file> is successful, C<undef> otherwise.
+
 =back
 
 =head1 AUTHOR
